From 02987af92cea736dfe6819200304f7e122c842f5 Mon Sep 17 00:00:00 2001
From: Ashutosh Bapat <ashutosh.bapat@enterprisedb.com>
Date: Tue, 31 Oct 2023 11:29:29 +0530
Subject: [PATCH v2 3/3] Use Relids instead of Bitmapset * in plannode.h

Most of the planner code uses Relids instead of Bitmapset * to declare a
bitmapset of RTIs. Fix plannode.h to do the same.

Ashutosh Bapat
---
 src/include/nodes/plannodes.h | 12 ++++++------
 1 file changed, 6 insertions(+), 6 deletions(-)

diff --git a/src/include/nodes/plannodes.h b/src/include/nodes/plannodes.h
index d40af8e59f..c835a4ec16 100644
--- a/src/include/nodes/plannodes.h
+++ b/src/include/nodes/plannodes.h
@@ -18,8 +18,8 @@
 #include "access/stratnum.h"
 #include "common/relpath.h"
 #include "lib/stringinfo.h"
-#include "nodes/bitmapset.h"
 #include "nodes/lockoptions.h"
+#include "nodes/pathnodes.h"
 #include "nodes/primnodes.h"
 
 
@@ -263,7 +263,7 @@ struct PartitionPruneInfo;		/* forward reference to struct below */
 typedef struct Append
 {
 	Plan		plan;
-	Bitmapset  *apprelids;		/* RTIs of appendrel(s) formed by this node */
+	Relids		apprelids;		/* RTIs of appendrel(s) formed by this node */
 	List	   *appendplans;
 	int			nasyncplans;	/* # of asynchronous plans */
 
@@ -287,7 +287,7 @@ typedef struct MergeAppend
 	Plan		plan;
 
 	/* RTIs of appendrel(s) formed by this node */
-	Bitmapset  *apprelids;
+	Relids		apprelids;
 
 	List	   *mergeplans;
 
@@ -714,8 +714,8 @@ typedef struct ForeignScan
 	List	   *fdw_private;	/* private data for FDW */
 	List	   *fdw_scan_tlist; /* optional tlist describing scan tuple */
 	List	   *fdw_recheck_quals;	/* original quals not in scan.plan.qual */
-	Bitmapset  *fs_relids;		/* base+OJ RTIs generated by this scan */
-	Bitmapset  *fs_base_relids; /* base RTIs generated by this scan */
+	Relids		fs_relids;		/* base+OJ RTIs generated by this scan */
+	Relids		fs_base_relids; /* base RTIs generated by this scan */
 	bool		fsSystemCol;	/* true if any "system column" is needed */
 } ForeignScan;
 
@@ -743,7 +743,7 @@ typedef struct CustomScan
 	List	   *custom_exprs;	/* expressions that custom code may evaluate */
 	List	   *custom_private; /* private data for custom code */
 	List	   *custom_scan_tlist;	/* optional tlist describing scan tuple */
-	Bitmapset  *custom_relids;	/* RTIs generated by this scan */
+	Relids		custom_relids;	/* RTIs generated by this scan */
 
 	/*
 	 * NOTE: The method field of CustomScan is required to be a pointer to a
-- 
2.39.2

